@@ -11,9 +11,20 @@ from orders.forms import CheckoutForm
 @transaction.atomic
 def checkout(request):
 
+    user = request.user
+    initial = {'mobile': '+380'}
+
+    if user.is_authenticated:
+        initial.update({
+            'first_name': user.first_name,
+            'last_name': user.last_name,
+            'email': user.email,
+        })
+
     form = CheckoutForm(
-        initial={'mobile': '+380'},
-        data=request.POST or None)
+        initial=initial,
+        data=request.POST or None
+    )
 
     if request.method == 'POST' and form.is_valid():
 
@@ -24,6 +35,9 @@ def checkout(request):
         order.delivery = form.fields['delivery'].get_delivery_method()
         order.address = form.fields['delivery'].get_address()
 
+        if user.is_authenticated:
+            order.user = request.user
+
         order.save()
 
         for item in cart.items:
